@@ -1,10 +1,5 @@
-from __future__ import unicode_literals
-
-
 from .common import InfoExtractor
-from ..compat import (
-    compat_urlparse,
-)
+from ..compat import compat_urlparse
 
 
 class RtmpIE(InfoExtractor):
